@@ -1,7 +1,7 @@
 /*
-  $Id: MbtServerBase.cxx 15155 2012-09-04 10:35:45Z sloot $
+  $Id: MbtServerBase.cxx 15831 2013-03-28 11:59:05Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/MbtServer/src/MbtServerBase.cxx $
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -88,13 +88,13 @@ namespace MbtServer {
 	  if ( !rest.empty() ){
 	    string tmp = lowercase(base);
 	    if ( tmp == "maxconn" ){
-	      if ( !stringTo( rest, maxConn ) ){
+	      if ( !TiCC::stringTo( rest, maxConn ) ){
 		cerr << "invalid value for maxconn" << endl;
 		return false;
 	      }
 	    }
 	    else if ( tmp == "port" ){
-	      if ( !stringTo( rest, serverPort ) ){
+	      if ( !TiCC::stringTo( rest, serverPort ) ){
 		cerr << "invalid value for port" << endl;
 		return false;
 	      }
@@ -187,7 +187,7 @@ namespace MbtServer {
 	usage();
 	exit( EXIT_FAILURE );
       }
-      serverPort = Timbl::stringTo<int>( val );
+      serverPort = TiCC::stringTo<int>( val );
       if ( serverPort < 1 || serverPort > 32767 ){
 	cerr << "-S option, portnumber invalid: " << serverPort << endl;
 	usage();
